# Matrix Meetling Bot

Ein Bot zur Verwaltung von **Jitsi-Meetings** über eine **Matrix-Instanz**. Mit diesem Bot lassen sich Jitsi-Sitzungen direkt über Matrix steuern und verwalten - ideal für automatisierte Konferenzen und Raumverwaltung.

---

## 🚀 Funktionen

- Starten und Verwalten von Jitsi-Meetings über Matrix
- Konfigurierbare Umgebungsvariablen
- Integration über Docker möglich

---

## 🛠️ Installation & Einrichtung

### 1. 🔑 Matrix-Zugangstoken generieren

Führe den folgenden Befehl aus, um einen Access-Token zu generieren. Ersetze `username`, `passwort` und die URL durch deine echten Zugangsdaten:

```bash
docker run --rm -it \
  -e MATRIX_USERNAME=username \
  -e MATRIX_PASSWORD=passwort \
  -e MATRIX_URL=https://matrixdomain.org \
  -v "$PWD:/app" \
  -w /app \
  git.h2-invent.com/meetling/matrix-bot:2.2.7 \
  node login.mjs
```

> 💡 **Hinweis:** Bewahre den generierten Token sicher auf - er wird zur Authentifizierung im Container verwendet.

---

## 🐳 Deployment mit Docker

### 1. 📂 Docker Compose Download

Falls noch nicht geschehen:

```bash
mkdir /opt/matrix-bot
cd /opt/matrix-bot
wget https://git.h2-invent.com/Meetling/matrix-bot/raw/branch/master/docker-compose.yml
```

### 2. ⚙️ Container starten

Baue das Docker-Image und starte den Container. Ersetze dabei:

- `tokenKommtHierHer`: den zuvor generierten Matrix Access-Token
- `https://matrixdomain.org`: deine Matrix-Instanz
- `https://jitsi-admin-url.de`: die Jitsi-Admin-URL

```bash
MATRIX_TOKEN=tokenKommtHierHer \
MATRIX_URL=https://matrixdomain.org \
JITSI_ADMIN_URL=https://jitsi-admin-url.de \
docker-compose up -d
```

### 3. 🔐 Berechtigungen setzen

Stelle sicher, dass das Docker-Volume korrekt gesetzt ist:


---

## ⚙️ Konfigurierbare Umgebungsvariablen

| Variable              | Beschreibung                                                    | Beispielwert                      |
|----------------------|------------------------------------------------------------------|-----------------------------------|
| `MATRIX_URL`         | URL der Matrix-Instanz                                           | `https://matrix.org`              |
| `MATRIX_TOKEN`       | Der generierte Access-Token                                      | _deinToken_                       |
| `MATRIX_PASSWORD`    | (Optional) Passwort des Matrix-Accounts                          | `geheimesPasswort`                |
| `JITSI_ADMIN_URL`    | URL zum Jitsi-Admin-Endpunkt                                     | `https://jitsi-admin.de`          |
| `MATRIX_DISPLAYNAME` | Anzeigename des Bots in Matrix                                   | `"Raumassistent"`                 |
| `SHOW_WARNING_OF_MIM`| Gibt an, ob Warnungen angezeigt werden sollen (true/false)       | `false`                           |

---

## 📌 Hinweise

- Stelle sicher, dass alle Zugangsdaten und Tokens **sicher gespeichert** und **nicht öffentlich geteilt** werden.
- Die in der README genannten URLs und Tokens dienen nur als **Beispiele** - bitte passe sie an deine Umgebung an.
- Der Bot bietet eine flexible Möglichkeit, Jitsi-Meetings über Matrix zu automatisieren.